\name{colorRampPalette}
\alias{colorRampPalette}
\alias{colorRamp}
\title{Extend a color palette to a color ramp }
\description{
These functions are useful for converting hand-designed `sequential' or
`diverging' color schemes into continous color ramps eg for image and
filled contour plots. Unfortunately the interpolation is still in RGB space.
}
\usage{
colorRampPalette(palette, bias = 1,method=c("spline","linear"))
colorRamp(palette, bias=1,method=c("spline","linear"))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{palette}{A vector of colors}
  \item{bias}{Bias >1 puts more colors at high values, <1 puts more at low values}
\item{method}{Interpolation method. Spline interpolation gives better results but can end up outside the valid RGB space with highly saturated palettes or those based on a small starting set.}
}

\value{
\code{colorRampPalette} returns a palette generating function like \code{\link{terrain.colors}} or \code{\link{heat.colors}} that takes an integer argument and generates a palette with that many colors.

\code{colorRamp} returns a color generating function, that takes a number between 0 and 1 and generates the corresponding color.

}
\author{Thomas Lumley}

\seealso{\url{www.colorbrewer.org} }

\examples{
   m<-outer(1:20,1:20,function(x,y) sin(sqrt(x*y)/3))

   redblue<-colorRampPalette(c("red","orange","blue"),method="linear")
   filled.contour(m,color.palette=redblue)

   yb<-colorRampPalette(c("yellow2","goldenrod","darkred"))
   filled.contour(m,color.palette=yb)

   yb<-colorRampPalette(c("yellow2","goldenrod","darkred"),bias=0.5)
   filled.contour(m,color.palette=yb)

   ## Two ColorBrewer sequential palettes
   ylOrBn4<-c("#FFFFD4", "#FED98E", "#FE9929","#CC4C02")
   ylGnBl5<-c("#FFFFCC","#C7E9B4","#7FCDBB","#40B6C4","#2C7FB8" ,"#253494")

   ylOrBn<-colorRampPalette(ylOrBn4,method="linear")
   ylGnBl<-colorRampPalette(ylGnBl5)
   filled.contour(m,color.palette=ylOrBn)
   filled.contour(m,color.palette=ylGnBl)


}
\keyword{color}% at least one, from doc/KEYWORDS

\eof
\name{dalton}
\alias{dalton}
\alias{dalton.colors}
\alias{redp}
\alias{redd}
\alias{greenp}
\alias{greend}
\alias{bluep}
\alias{blued}
\non_function{}
\title{Effects of daltonism (red-green color blindness)}
\description{
  A 256-color palette as it would appear with normal vision, and with
  two types of red-green colorblindness: protanopia and deuteronopia.
}
\usage{data(dalton)
data(dalton.colors)}
\format{
  \code{dalton}{  A 256x3x3 array. The columns index the red, green and blue color
    values, the layers index the vision type.}
  \code{dalton.colors}{A data frame of colors, with column names
    \code{normal}, \code{protan}, \code{deutan}.}
}
\source{
\url{http://tsi.enst.fr/~brettel/CRA24/table2.html}
}
\references{
F. Vinot, H. Brettel and J. D. Mollon (1999) Digital video colourmaps for checking the legibility of displays by dichromats. Color Research and Application 24, 243-252.
}
\examples{
data(dalton)
 par(mfrow=c(3,1))
 image(matrix(1:256,128),col=dalton.colors$deutan)
 image(matrix(1:256,128),col=dalton.colors$protan)
 image(matrix(1:256,128),col=dalton.colors$normal)


}
\keyword{datasets}

\eof
\name{dichromat}
\alias{dichromat}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Remove red-green distinctions from colours}
\description{
  Collapses red-green color distinctions to approximate the effect of
  the two common forms of red-green colour blindness, protanopia and
  deuteranopia. 
}
\usage{
dichromat(colours, type = c("deutan", "protan"))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{colours}{A vector of R colors, either color names or color hex strings}
  \item{type}{Type of color-blindness to simulate}
}
\details{
  Someone with the specified form of red-green colour blindness will
  find that the transformation has little effect on the appearance of
  colours.  Colours that are indistinguishable after transformation were
  likely indistinguishable to them before transformation.  About 10\% of
  men (and almost no women) have red-green colour blindness.
}
\value{
  A vector of R colors
}
\author{Thomas Lumley}
\references{
F. Vinot, H. Brettel and J. D. Mollon (1999) Digital video colourmaps for checking the legibility of displays by dichromats. Color Research and Application 24, 243-252.
}
\examples{
## from example(pie)
 par(mfrow=c(2,2))
 pie.sales <- c(0.12, 0.3, 0.26, 0.16, 0.04, 0.12)
 names(pie.sales) <- c("Blueberry", "Cherry",
         "Apple", "Boston Cream", "Other", "Vanilla Cream")
 pie(pie.sales) # default colours
 pie(pie.sales,
       col = c("purple", "violetred1", "green3", "cornsilk", "cyan", "white"))
 pie(pie.sales,col=dichromat( c("white", "lightblue", "mistyrose", "lightcyan", 
                "lavender", "cornsilk"))) # default colours
 pie(pie.sales,
       col =dichromat(c("purple", "violetred1", "green3", "cornsilk", "cyan", "white")))


## standard color schemes
pie(rep(1,10),col=heat.colors(10))
pie(rep(1,10),col=dichromat(heat.colors(10)))
pie(rep(1,8),col=palette())
pie(rep(1,8),col=dichromat(palette()))

pie(rep(1,15),col=topo.colors(15))
pie(rep(1,15),col=dichromat(topo.colors(15)))
pie(rep(1,15),col=terrain.colors(15))
pie(rep(1,15),col=dichromat(terrain.colors(15)))

pie(rep(1,15),col=cm.colors(15))
pie(rep(1,15),col=dichromat(cm.colors(15)))
bluescale<-colorRampPalette(c("#FFFFCC","#C7E9B4","#7FCDBB","#40B6C4","#2C7FB8" ,"#253494"))
pie(rep(1,15),col=bluescale(15))
pie(rep(1,15),col=dichromat(bluescale(15)))

par(mfrow=c(2,3))
x<-matrix(rnorm(10*10),10)
redgreen<-colorRampPalette(c("red","green3"),method="linear")
image(1:10,1:10,x, col=bluescale(10),
main="blue-yellow scale")
image(1:10,1:10,x, col=dichromat(bluescale(10)), main="deutan")
image(1:10,1:10,x,col=dichromat(bluescale(10),"protan"), main="protan")

image(1:10,1:10,x, col=redgreen(10),
main="red-green scale")
image(1:10,1:10,x, col=dichromat(redgreen(10)), main="deutan")
image(1:10,1:10,x, col=dichromat(redgreen(10),"protan"), main="protan")

}
\keyword{color}% at least one, from doc/KEYWORDS


\eof
